@@ -3,10 +3,13 @@ import typer.main
 
 typer.main.HAS_RICH = False
 
+app = typer.Typer()
 
+
+@app.command()
 def main(name: str = "morty"):
     print(name + 3)
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
