@@ -19,6 +19,19 @@ def test_eoferror():
     assert result.exit_code == 1
 
 
+def test_keyboardinterrupt():
+    # Mainly for coverage/completeness
+    app = typer.Typer()
+
+    @app.command()
+    def main():
+        raise KeyboardInterrupt()
+
+    result = runner.invoke(app)
+    assert result.exit_code == 130
+    assert result.stdout == ""
+
+
 def test_oserror():
     # Mainly for coverage/completeness
     app = typer.Typer()
