@@ -3,6 +3,7 @@ import subprocess
 import sys
 import typing
 from pathlib import Path
+from typing import Annotated
 from unittest import mock
 
 import click
@@ -14,7 +15,6 @@ from typer.core import _split_opt
 from typer.main import solve_typer_info_defaults, solve_typer_info_help
 from typer.models import ParameterInfo, TyperInfo
 from typer.testing import CliRunner
-from typing_extensions import Annotated
 
 from .utils import requires_completion_permission
 
@@ -148,14 +148,14 @@ def test_callback_3_untyped_parameters():
 def test_callback_4_list_none():
     app = typer.Typer()
 
-    def names_callback(ctx, param, values: typing.Optional[typing.List[str]]):
+    def names_callback(ctx, param, values: typing.Optional[list[str]]):
         if values is None:
             return values
         return [value.upper() for value in values]
 
     @app.command()
     def main(
-        names: typing.Optional[typing.List[str]] = typer.Option(
+        names: typing.Optional[list[str]] = typer.Option(
             None, "--name", callback=names_callback
         ),
     ):
@@ -172,14 +172,14 @@ def test_callback_4_list_none():
 
 
 def test_empty_list_default_generator():
-    def empty_list() -> typing.List[str]:
+    def empty_list() -> list[str]:
         return []
 
     app = typer.Typer()
 
     @app.command()
     def main(
-        names: Annotated[typing.List[str], typer.Option(default_factory=empty_list)],
+        names: Annotated[list[str], typer.Option(default_factory=empty_list)],
     ):
         print(names)
 
