@@ -1,18 +1,30 @@
+import importlib
 import os
 import subprocess
 import sys
+from types import ModuleType
 
+import pytest
 from typer.testing import CliRunner
 
-from docs_src.commands.help import tutorial005 as mod
-
-app = mod.app
-
 runner = CliRunner()
 
 
-def test_help():
-    result = runner.invoke(app, ["--help"])
+@pytest.fixture(
+    name="mod",
+    params=[
+        pytest.param("tutorial005_py39"),
+        pytest.param("tutorial005_an_py39"),
+    ],
+)
+def get_mod(request: pytest.FixtureRequest) -> ModuleType:
+    module_name = f"docs_src.commands.help.{request.param}"
+    mod = importlib.import_module(module_name)
+    return mod
+
+
+def test_help(mod: ModuleType):
+    result = runner.invoke(mod.app, ["--help"])
     assert result.exit_code == 0
     assert "create" in result.output
     assert "Create a new shiny user. ✨" in result.output
@@ -22,8 +34,8 @@ def test_help():
     assert "Some internal utility function to delete." not in result.output
 
 
-def test_help_create():
-    result = runner.invoke(app, ["create", "--help"])
+def test_help_create(mod: ModuleType):
+    result = runner.invoke(mod.app, ["create", "--help"])
     assert result.exit_code == 0
     assert "Create a new shiny user. ✨" in result.output
     assert "The username to be created" in result.output
@@ -31,8 +43,8 @@ def test_help_create():
     assert "Some internal utility function to create." not in result.output
 
 
-def test_help_delete():
-    result = runner.invoke(app, ["delete", "--help"])
+def test_help_delete(mod: ModuleType):
+    result = runner.invoke(mod.app, ["delete", "--help"])
     assert result.exit_code == 0
     assert "Delete a user with USERNAME." in result.output
     assert "The username to be deleted" in result.output
@@ -40,19 +52,19 @@ def test_help_delete():
     assert "Some internal utility function to delete." not in result.output
 
 
-def test_create():
-    result = runner.invoke(app, ["create", "Camila"])
+def test_create(mod: ModuleType):
+    result = runner.invoke(mod.app, ["create", "Camila"])
     assert result.exit_code == 0
     assert "Creating user: Camila" in result.output
 
 
-def test_delete():
-    result = runner.invoke(app, ["delete", "Camila"])
+def test_delete(mod: ModuleType):
+    result = runner.invoke(mod.app, ["delete", "Camila"])
     assert result.exit_code == 0
     assert "Deleting user: Camila" in result.output
 
 
-def test_script():
+def test_script(mod: ModuleType):
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
         capture_output=True,
