@@ -1,29 +1,39 @@
+import importlib
 import subprocess
 import sys
 from pathlib import Path
+from types import ModuleType
 
-import typer
+import pytest
 from typer.testing import CliRunner
 
-from docs_src.parameter_types.file import tutorial001 as mod
-
 runner = CliRunner()
 
-app = typer.Typer()
-app.command()(mod.main)
+
+@pytest.fixture(
+    name="mod",
+    params=[
+        pytest.param("tutorial001_py39"),
+        pytest.param("tutorial001_an_py39"),
+    ],
+)
+def get_mod(request: pytest.FixtureRequest) -> ModuleType:
+    module_name = f"docs_src.parameter_types.file.{request.param}"
+    mod = importlib.import_module(module_name)
+    return mod
 
 
-def test_main(tmpdir):
+def test_main(tmpdir, mod: ModuleType):
     config_file = Path(tmpdir) / "config.txt"
     config_file.write_text("some settings\nsome more settings")
-    result = runner.invoke(app, ["--config", f"{config_file}"])
+    result = runner.invoke(mod.app, ["--config", f"{config_file}"])
     config_file.unlink()
     assert result.exit_code == 0
     assert "Config line: some settings" in result.output
     assert "Config line: some more settings" in result.output
 
 
-def test_script():
+def test_script(mod: ModuleType):
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
         capture_output=True,
